import sequelizeConnection from "../seqConnection";
import { DataTypes, Model, Optional } from "sequelize";

interface BoatAttributes {
  id: number;
  name: string;
  status: boolean;
  active: boolean;
  seats: number;
}

export interface BoatAttributesInput extends Optional<BoatAttributes, "id"> { }
export interface BoatAttributesOutput extends Required<BoatAttributes> { }
class Boat extends Model<BoatAttributes> implements BoatAttributes {
  public id!: number;
  public name!: string;
  public status: boolean;
  public active: boolean;
  public seats: number;

  public readonly createdAt!: Date;
  public readonly updatedAt!: Date;
}
Boat.init(
  {
    id: {
      type: DataTypes.INTEGER,
      primaryKey: true,
    },
    name: {
      type: new DataTypes.STRING(),
      allowNull: false,
    },
    status: {
      type: DataTypes.BOOLEAN,
      allowNull: false,
    },
    active: {
      type: DataTypes.BOOLEAN,
      allowNull: false,
    },
    seats: {
      type: new DataTypes.INTEGER(),
      allowNull: false,
    },
  },
  {
    tableName: "boat",
    sequelize: sequelizeConnection,
  }
);

export const create = async (payload: Boat): Promise<BoatAttributesOutput> => {
  return await Boat.create(payload);
};

export const update = async (
  id: number,
  payload: Partial<BoatAttributesInput>
): Promise<BoatAttributesOutput> => {
  const boat = await Boat.findByPk(id);
  if (!boat) {
    throw new Error("not found");
  }
  return await (boat as Boat).update(payload);
};

export const getById = async (id: number): Promise<Boat> => {
  const boat = await Boat.findByPk(id);
  if (!boat) {
    throw new Error("not found");
  }
  return boat;
};

export const deleteById = async (id: number): Promise<boolean> => {
  const deletedBoatCount = await Boat.destroy({
    where: { id },
  });
  return !!deletedBoatCount;
};

export const getAll = async (): Promise<BoatAttributesOutput[]> => {
  return Boat.findAll();
};
export const BoatService = {
  create,
  update,
  getById,
  deleteById,
  getAll,
};

export default Boat;
